@@ -33,21 +33,17 @@
 #include "kileviewmanager.h"
 #include "kileconfig.h"
 #include "kileedit.h"
+#include "kiledebug.h"
 
 namespace KileDocument
 {
 
-	//static QRegExp::QRegExp reRef("^\\\\(pageref|ref)\\{");
-	//static QRegExp::QRegExp reCite("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{");
-	//static QRegExp::QRegExp reRefExt("^\\\\(pageref|ref)\\{[^\\{\\}\\\\]+,$");
-	//static QRegExp::QRegExp reCiteExt("^\\\\(c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext)\\{[^\\{\\}\\\\]+,$");
-
 	static QRegExp::QRegExp reRef;
 	static QRegExp::QRegExp reRefExt;
 	static QRegExp::QRegExp reCite;
 	static QRegExp::QRegExp reCiteExt;
 	static QRegExp::QRegExp reNotRefChars("[^a-zA-Z0-9_@\\.\\+\\-\\*\\:]");
-	static QRegExp::QRegExp reNotCiteChars("[^a-zA-Z0-9_@]");
+	static QRegExp::QRegExp reNotCiteChars("[^a-zA-Z0-9_@\\-\\:]");
 
 	CodeCompletion::CodeCompletion(KileInfo *info) : m_ki(info), m_view(0L)
 	{
@@ -113,23 +109,41 @@ namespace KileDocument
 			int pos = currentline.findRev('\\');
 			if ( pos >= 0 )
 			{
-
 				QString command = currentline.mid(pos,column-pos);
- 				if ( command.find(reRef) != -1 )
-				{
-					startpattern = command.right(command.length()-reRef.cap(0).length());
-					if ( startpattern.find(reNotRefChars) == -1 )
+				KILE_DEBUG() << "pos=" << pos << ",column=" << column << ",currentline=" << currentline << ",command=" << command << endl;
+
+				if( command.find(reRefExt) != -1 ){
+					KILE_DEBUG() << "reRefExt" << endl;
+					startpattern = command.right(command.length()-reRefExt.cap(0).length());
+					KILE_DEBUG() << "startpattern=" << startpattern << endl;
+					if ( startpattern.find(reNotRefChars) == -1 ){
 						return CodeCompletion::ctReference ;
+					}
 				}
-				else if ( command.find(reCite) != -1 )
-				{
+ 				else if ( command.find(reRef) != -1 ){
+					startpattern = command.right(command.length()-reRef.cap(0).length());
+					KILE_DEBUG() << "startpattern=" << startpattern << endl;
+					if ( startpattern.find(reNotRefChars) == -1 ){
+						return CodeCompletion::ctReference ;
+					}
+				}
+				else if( command.find(reCiteExt) != -1 ){
+					KILE_DEBUG() << "reCiteExt" << endl;
+					startpattern = command.right(command.length()-reCiteExt.cap(0).length());
+					KILE_DEBUG() << "startpattern=" << startpattern << endl;
+					if ( startpattern.find(reNotCiteChars) == -1 ){
+						return CodeCompletion::ctCitation;
+					}
+				}
+				else if ( command.find(reCite) != -1 ){
 					startpattern = command.right(command.length()-reCite.cap(0).length());
-					if ( startpattern.find(reNotCiteChars) == -1 )
-						return CodeCompletion::ctCitation ;
+					KILE_DEBUG() << "startpattern=" << startpattern << endl;
+					if ( startpattern.find(reNotCiteChars) == -1 ){
+						return CodeCompletion::ctCitation;
+					}
 				}
 			}
 		}
-
 		return CodeCompletion::ctNone;
 	}
 
@@ -207,13 +221,13 @@ namespace KileDocument
 		QString references = getCommandList(KileDocument::CmdAttrReference);
 		references.replace("*","\\*");
 		reRef.setPattern("^\\\\(" + references + ")\\{");
-		reRefExt.setPattern("^\\\\(" + references + ")\\{[^\\{\\}\\\\]+,$");
+		reRefExt.setPattern("^\\\\(" + references + ")\\{[^\\{\\}\\\\]+,");
 
 		// build list of citations
 		QString citations = getCommandList(KileDocument::CmdAttrCitations);
 		citations.replace("*","\\*");
 		reCite.setPattern("^\\\\(((c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext))" + citations +  ")\\{");
-		reCiteExt.setPattern("^\\\\(((c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext))" + citations + ")\\{[^\\{\\}\\\\]+,$");
+		reCiteExt.setPattern("^\\\\(((c|C|noc)(ite|itep|itet|itealt|itealp|iteauthor|iteyear|iteyearpar|itetext))" + citations + ")\\{[^\\{\\}\\\\]+,");
 	}
 
 	QString CodeCompletion::getCommandList(KileDocument::CmdAttribute attrtype)
@@ -343,9 +357,9 @@ namespace KileDocument
 	void CodeCompletion::completeWord(const QString &text, CodeCompletion::Mode mode)
 	{
 		KILE_DEBUG() << "==CodeCompletion::completeWord(" << text << ")=========" << endl;
-		//KILE_DEBUG() << "\tm_view = " << m_view << endl;
+		KILE_DEBUG() << "\tm_view = " << m_view << endl;
 		if ( !m_view) return;
-		//KILE_DEBUG() << "ok" << endl;
+		KILE_DEBUG() << "ok" << endl;
 
 		// remember all parameters (view, pattern, length of pattern, mode)
 		m_text = text;
@@ -364,7 +378,7 @@ namespace KileDocument
 			QString s = doc->textLine(m_ycursor);
 			int pos = s.findRev("\\",m_xcursor);
 			if (pos < 0) {
-				//KILE_DEBUG() << "\tfound no backslash! s=" << s << endl;
+				KILE_DEBUG() << "\tfound no backslash! s=" << s << endl;
 				return;
 			}
 			m_xstart = pos;
@@ -401,7 +415,7 @@ namespace KileDocument
 		QString pattern = ( m_mode != cmEnvironment ) ? text : "\\begin{" + text;
 		uint n = countEntries( pattern, &list, &entry, &type );
 
-		//KILE_DEBUG() << "entries = " << n << endl;
+		KILE_DEBUG() << "entries = " << n << endl;
 
 		// nothing to do
 		if ( n == 0 )
@@ -490,6 +504,7 @@ namespace KileDocument
 
 	void CodeCompletion::CompletionAborted()
 	{
+		KILE_DEBUG() << "CodeCompletion::CompletionAborted()" << endl;
 		// aborted: undo if kile completion is active
 		if ( m_inprogress && m_undo && m_view )
 		{
@@ -518,7 +533,7 @@ namespace KileDocument
 	QString CodeCompletion::filterCompletionText( const QString &text, const QString &type )
 	{
 		static QRegExp::QRegExp reEnv = QRegExp("^\\\\(begin|end)[^a-zA-Z]+");
-		//KILE_DEBUG() << "   complete filter: " << text << " type " << type << endl;
+		KILE_DEBUG() << "   complete filter: " << text << " type " << type << endl;
 		m_type = getType( text );    // remember current type
 
 		if ( text!="\\begin{}" && reEnv.search(text)!=-1 )
@@ -1031,11 +1046,16 @@ namespace KileDocument
 
 	void CodeCompletion::editComplete(Kate::View *view, Mode mode)
 	{
-		m_view = view;
+		KILE_DEBUG() << "void CodeCompletion::editComplete(Kate::View *view, Mode "<< mode << ")" << endl;
+		KILE_DEBUG() << "m_inprogress=" << m_inprogress << ", isActive()=" << isActive() << endl;
+		m_view = view; 
 
-		if ( !m_view || !isActive() || inProgress() )
+		if ( !m_view || !isActive() )
 			return ;
+		
+		m_inprogress=true;
 
+		KILE_DEBUG() << "proceeded" << endl;
 		// check for a special case: call from inside of a reference command
 		if ( mode==cmLatex )
 		{
@@ -1063,21 +1083,11 @@ namespace KileDocument
 			else
 				editCompleteList(type);
 		}
-		//little hack to make multiple insertions like \cite{test1,test2} possible (only when
-		//completion is invoke explicitly using ctrl+space.
-		else if ( m_view->getDoc() )
-		{
-			QString currentline = m_view->getDoc()->textLine(m_view->cursorLine()).left(m_view->cursorColumnReal() + 1);
-			if ( currentline.find(reCiteExt) != -1 )
-				editCompleteList(ctCitation);
-			else if ( currentline.find(reRefExt) != -1 )
-				editCompleteList(ctReference);
-		}
 	}
 
 	void CodeCompletion::editCompleteList(Type type,const QString &pattern)
 	{
-		//KILE_DEBUG() << "==editCompleteList=============" << endl;
+		KILE_DEBUG() << "==editCompleteList=============" << endl;
 		m_keylistType = type;
 		if ( type == ctReference )
 			completeFromList(info()->allLabels(),pattern);
@@ -1094,9 +1104,9 @@ namespace KileDocument
 
 	void CodeCompletion::slotCompletionDone(KTextEditor::CompletionEntry entry)
 	{
-		//KILE_DEBUG() << "==slotCompletionDone (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
+		KILE_DEBUG() << "==slotCompletionDone (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		CompletionDone(entry);
-
+		
 		// if kile completion was active, look if we need to show an additional list
 		if ( m_kilecompletion )
 		{
@@ -1117,25 +1127,25 @@ namespace KileDocument
 
 	void CodeCompletion::slotCompleteValueList()
 	{
-		//KILE_DEBUG() << "==slotCompleteValueList (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
+		KILE_DEBUG() << "==slotCompleteValueList (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		m_completeTimer->stop();
 		editCompleteList(getType());
 	}
 
 	void CodeCompletion::slotCompletionAborted()
 	{
-		//KILE_DEBUG() << "==slotCompletionAborted (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
+		KILE_DEBUG() << "==slotCompletionAborted (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		CompletionAborted();
 	}
 
 	void CodeCompletion::slotFilterCompletion( KTextEditor::CompletionEntry* c, QString *s )
 	{
-		//KILE_DEBUG() << "==slotFilterCompletion (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
+		KILE_DEBUG() << "==slotFilterCompletion (" << m_kilecompletion << "," << m_inprogress << ")=============" << endl;
 		if ( inProgress() )                 // dani 28.09.2004
 		{
-			//KILE_DEBUG() << "\tin progress: s=" << *s << endl;
+			KILE_DEBUG() << "\tin progress: s=" << *s << endl;
 			*s = filterCompletionText( c->text, c->type );
-			//KILE_DEBUG() << "\tfilter --->" << *s << endl;
+			KILE_DEBUG() << "\tfilter --->" << *s << endl;
 			m_inprogress = false;
 			m_kilecompletion = true;
 		}
@@ -1143,7 +1153,7 @@ namespace KileDocument
 
 	void CodeCompletion::slotCharactersInserted(int, int, const QString& string )
 	{
-		//KILE_DEBUG() << "==slotCharactersInserted (" << m_kilecompletion << "," << m_inprogress << ", " << m_ref << ", " << string << ")=============" << endl;
+		KILE_DEBUG() << "==slotCharactersInserted (" << m_kilecompletion << "," << m_inprogress << ", " << m_ref << ", " << string << ")=============" << endl;
 
 		if ( !inProgress() && m_autoDollar && string=="$" )
 		{
@@ -1182,15 +1192,15 @@ namespace KileDocument
 		if ( found )
 		{
 			int wordlen = word.length();
-			//KILE_DEBUG() << "   auto completion: word=" << word << " mode=" << m_mode << " inprogress=" << inProgress() << endl;
+			KILE_DEBUG() << "   auto completion: word=" << word << " mode=" << m_mode << " inprogress=" << inProgress() << endl;
 			if ( inProgress() )               // continue a running mode?
 			{
-				//KILE_DEBUG() << "   auto completion: continue current mode" << endl;
+				KILE_DEBUG() << "   auto completion: continue current mode" << endl;
 				completeWord(word, m_mode);
 			}
 			else if ( word.at( 0 )=='\\' && m_autocomplete && wordlen>=m_latexthreshold)
 			{
-				//KILE_DEBUG() << "   auto completion: latex mode" << endl;
+				KILE_DEBUG() << "   auto completion: latex mode" << endl;
 				if ( string.at( 0 ).isLetter() )
 				{
 					completeWord(word, cmLatex);
@@ -1202,7 +1212,7 @@ namespace KileDocument
 			}
 			else if ( word.at(0).isLetter() && m_autocompletetext && wordlen>=m_textthreshold)
 			{
-				//KILE_DEBUG() << "   auto completion: document mode" << endl;
+				KILE_DEBUG() << "   auto completion: document mode" << endl;
 				completeWord(word,cmDocumentWord);
 			}
 		}
@@ -1286,7 +1296,7 @@ namespace KileDocument
 	void CodeCompletion::getDocumentWords(const QString &text,
 	                                      QValueList<KTextEditor::CompletionEntry> &list)
 	{
-		//KILE_DEBUG() << "getDocumentWords: " << endl;
+		KILE_DEBUG() << "getDocumentWords: " << endl;
 		list.clear();
 
 		QRegExp reg("(\\\\?\\b" + QString(text[0]) + "[^\\W\\d_]+)\\b");
