@@ -1,8 +1,8 @@
 /***************************************************************************
-    date                 : Jan 12 2006
-    version              : 0.30
-    copyright            : (C) 2004-2006 by Holger Danielsson
-    email                : holger.danielsson@t-online.de
+    date                 : Mar 21 2007
+    version              : 0.40
+    copyright            : (C) 2004-2007 by Holger Danielsson
+    email                : holger.danielsson@versanet.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -25,6 +25,7 @@
 #include <kconfig.h>
 
 #include "latexcmd.h"
+#include "kileabbrevview.h"
 
 //default bullet char (a cross)
 static const QChar s_bullet_char = QChar(0xd7);
@@ -85,6 +86,9 @@ public:
 
 	void readConfig(KConfig *config);
 	void readKateConfigFlags(KConfig *config);
+	void saveLocalChanges();
+
+	void setAbbreviationListview(KileAbbrevView *listview);
 
 public slots:
 	//in these two methods we should set m_view
@@ -97,6 +101,10 @@ public slots:
 
 	void slotFilterCompletion(KTextEditor::CompletionEntry* c,QString *s);
 
+	// a abbreviation was modified ind the abbreviation view (add, edit or delete)
+	// so the abbreviation list was must also be updated
+	void slotUpdateAbbrevList(const QString &ds, const QString &as);
+
 private:
 	void completeWord(const QString &text, CodeCompletion::Mode mode);
 	QString filterCompletionText(const QString &text, const QString &type);
@@ -104,8 +112,8 @@ private:
 	void CompletionDone(KTextEditor::CompletionEntry);
 	void CompletionAborted();
 
-	void completeFromList(const QStringList *list);
-	void editCompleteList(KileDocument::CodeCompletion::Type type);
+	void completeFromList(const QStringList *list,const QString &pattern=QString::null);
+	void editCompleteList(KileDocument::CodeCompletion::Type type,const QString &pattern=QString::null);
 	bool getCompleteWord(bool latexmode, QString &text, KileDocument::CodeCompletion::Type &type);
 	bool getReferenceWord(QString &text);
 	bool oddBackslashes(const QString& text, int index);
@@ -113,6 +121,11 @@ private:
 	void appendNewCommands(QValueList<KTextEditor::CompletionEntry> & list);
 	void getDocumentWords(const QString &text,QValueList<KTextEditor::CompletionEntry> &list);
 
+	bool completeAutoAbbreviation(const QString &text);
+	QString getAbbreviationWord(uint row, uint col);
+
+	CodeCompletion::Type insideReference(QString &startpattern);
+
 private:
 	// wordlists
 	QValueList<KTextEditor::CompletionEntry> m_texlist;
@@ -130,6 +143,9 @@ private:
 	bool m_closeenv;
 	bool m_autocomplete;
 	bool m_autocompletetext;
+	bool m_autocompleteabbrev;
+	bool m_citationMove;
+	bool m_autoDollar;
 	int  m_latexthreshold;
 	int  m_textthreshold;
 
@@ -148,6 +164,11 @@ private:
 
 	// special types: ref, bib
 	CodeCompletion::Type m_type;
+	CodeCompletion::Type m_keylistType;
+
+	// local abbreviation
+	QString m_localAbbrevFile;
+	KileAbbrevView *m_abbrevListview;
 
 	// internal parameter
 	Kate::View *m_view;                  // View
@@ -167,7 +188,7 @@ private:
 	QString stripParameter(const QString &text);
 
 	void setWordlist(const QStringList &files,const QString &dir, QValueList<KTextEditor::CompletionEntry> *entrylist);
-	void readWordlist(QStringList &wordlist, const QString &filename);
+	void readWordlist(QStringList &wordlist, const QString &filename, bool global);
 	void addCommandsToTexlist(QStringList &wordlist);
 	
 	void setReferences();
@@ -177,6 +198,12 @@ private:
 	void setCompletionEntriesTexmode(QValueList<KTextEditor::CompletionEntry> *list, const QStringList &wordlist);
 
 	uint countEntries(const QString &pattern, QValueList<KTextEditor::CompletionEntry> *list, QString *entry, QString *type);
+
+	void addAbbreviationEntry( const QString &entry );
+	void deleteAbbreviationEntry( const QString &entry );
+	QString findExpansion(const QString &abbrev);
+
+	void autoInsertDollar();
 };
 
 }
