@@ -13,6 +13,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "configcheckerdlg.h"
+
 #include <qfileinfo.h>
 #include <qlayout.h>
 #include <qlabel.h>
@@ -25,9 +27,8 @@
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <klistbox.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 
-#include "configcheckerdlg.h"
 #include "configcheckerwidget.h"
 
 namespace KileDialog
@@ -41,7 +42,7 @@ ResultItem::ResultItem(KListBox *lb, const QString &tool, int status, const QVal
 		QString itemcolor = "black";
 		if ( tests[i].status() == ConfigTest::Failure ) itemcolor = "#FFA201";
 		else if ( tests[i].status() == ConfigTest::Critical ) itemcolor = "#AA0000";
-		rt += QString("<li><b><font color=\"%1\">%2</font></b>: %3</li>").arg(itemcolor).arg(tests[i].name()).arg(tests[i].resultText());
+		rt += QString("<li><b><font color=\"%1\">%2</font></b>: &nbsp;%3</li>").arg(itemcolor).arg(tests[i].name()).arg(tests[i].resultText());
 	}
 	rt += "</ul>";
 
@@ -61,7 +62,7 @@ ResultItem::ResultItem(KListBox *lb, const QString &tool, int status, const QVal
 	m_richText->setWidth(listBox()->width());
 
 	//this is for sorting only
-	setText(QString::number(status) + ":" + tool);
+	setText(QString::number(status) + ':' + tool);
 }
 
 void ResultItem::paint(QPainter *p)
