@@ -12,6 +12,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+#include "configtester.h"
+
 #include <qfile.h>
 
 #include <kio/netaccess.h>
@@ -21,12 +24,12 @@
 #include <ktempdir.h>
 #include <ksimpleconfig.h>
 #include <kglobal.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 
 #include "kiletoolmanager.h"
+#include "kileinfo.h"
 #include "kileconfig.h"
 #include "kiletool.h"
-#include "configtester.h"
 
 ConfigTest::ConfigTest() :
 	m_name(QString::null),
@@ -71,7 +74,12 @@ QString ConfigTest::resultText() const
 	else if ( status() == Critical ) str = criticalMessage(m_name);
 
 	if ( m_name == "binary" )
-		return str + " (" + m_altArg + " => " + m_arg + ")";
+	{
+		str += " (" + m_altArg + " => " + m_arg + ')';
+		if ( status()==Failure && s_msgFailure.contains(m_altArg) ) 
+			str += QString("<br>(%1)").arg( s_msgFailure[m_altArg] );
+		return str;
+	}
 	else if ( m_name == "version" )
 		return m_arg;
 	else
@@ -131,6 +139,11 @@ Tester::Tester(QObject *parent, const char *name) : QObject(parent, name), m_pro
 	ConfigTest::addSuccessMessage("src", i18n("Supported, use the 'Modern' configuration for (La)TeX and PDF(La)TeX to auto-enable inverse and forward search capabilities."));
 	ConfigTest::addFailureMessage("src", i18n("Not supported, use the srcltx package to enable the inverse and forward search capabilities."));
 
+	// add some special messages, when programs are not installed, 
+	// which are not needed, but probably useful for the work with kile
+	ConfigTest::addFailureMessage("dvipng", i18n("You can't use the png preview for mathgroups in the bottom bar."));
+	ConfigTest::addFailureMessage("convert", i18n("You can't use the png previews with conversions 'dvi->ps->png' and 'pdf->png'."));
+	ConfigTest::addFailureMessage("acroread", i18n("You can't open pdf documents with Acrobat Reader. But you could use KPDF or KGhostView."));
 }
 
 
@@ -149,18 +162,18 @@ void Tester::saveResults(const KURL & dest)
 void Tester::runTests()
 {
 	QString srcdir = KGlobal::dirs()->findResourceDir("appdata","test/runTests.sh") + "test";
-	kdDebug() << "Tester::runTests: srcdir = " << srcdir << endl;
+	KILE_DEBUG() << "Tester::runTests: srcdir = " << srcdir << endl;
 	m_tempDir = new KTempDir();
 	QString destdir = m_tempDir->name();
-	kdDebug() << "Tester::runTests: destdir = " << destdir << endl;
+	KILE_DEBUG() << "Tester::runTests: destdir = " << destdir << endl;
 	m_resultsFile = destdir + "results.rc";
 
 	QString shellname = KGlobal::dirs()->findExe("sh");
-	kdDebug() << "Tester::runTests: shellname = " << shellname << endl;
+	KILE_DEBUG() << "Tester::runTests: shellname = " << shellname << endl;
 	m_process = new KShellProcess(QFile::encodeName( shellname ));
 	if (! KileConfig::teXPaths().isEmpty())
 	{
-		m_process->setEnvironment("TEXINPUTS", KileTool::expandEnvironmentVars( KileConfig::teXPaths() + ":$TEXINPUTS"));
+		m_process->setEnvironment("TEXINPUTS", KileInfo::expandEnvironmentVars( KileConfig::teXPaths() + ":$TEXINPUTS"));
 	}
 	*m_process << "cd " + KShellProcess::quote(destdir) + " && ";
 	*m_process << "cp " + KShellProcess::quote(srcdir) +"/* " + KShellProcess::quote(destdir) + " && ";
