@@ -10,14 +10,20 @@
 //
 //
 
+// 2007-03-17 dani
+//  - select a single LaTeX command with CTRL+MouseDblClick-left
+//    (such a double click on the middle part '\def' of '\abd\def\ghi'
+//    will select only '\def\', not the whole text, as it does now)
+
+#include "kileeventfilter.h"
+
 #include <qevent.h>
 
 #include <kate/view.h>
 #include <kate/document.h>
-#include <kdebug.h>
+#include "kiledebug.h"
 
 #include "kileedit.h"
-#include "kileeventfilter.h"
 #include "kileconfig.h"
 
 KileEventFilter::KileEventFilter(KileDocument::EditorExtension *edit) : m_edit(edit)
@@ -47,6 +53,15 @@ bool KileEventFilter::eventFilter(QObject *o, QEvent *e)
 			return m_edit->eventInsertEnvironment( (Kate::View*) o->parent() );
 		}
 	}
+	else if ( e->type() == QEvent::MouseButtonDblClick)
+	{
+		QMouseEvent *me = (QMouseEvent*) e;
+		if ( me->button()==LeftButton && ((me->state() & Qt::ControlButton) == Qt::ControlButton) )
+		{
+			m_edit->selectWord(KileDocument::EditorExtension::smTex);
+			return true;
+		}
+	}
 
 	//pass this event on
 	return false;
