@@ -19,15 +19,19 @@
 #include <qstring.h>
 #include <qptrlist.h>
 #include <qmap.h>
+#include <qscrollview.h>
 
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <kurl.h>
 
+#include "kileconstants.h"
+#include "kileextensions.h"
 #include "kiletoolmanager.h"
 #include "kilestdtools.h"
 #include "latexoutputfilter.h"
 #include "latexoutputinfo.h"
-#include "latexcmd.h"         
+#include "latexcmd.h"
+#include "kileconfig.h"
 
 class QWidget;
 
@@ -41,30 +45,35 @@ class KileEventFilter;
 namespace Kate { class Document;}
 
 class KileBottomBar;
-namespace KileDocument { class Manager; class EditorExtension; }
+namespace KileDocument { class Extensions; class Manager; class EditorExtension; }
 namespace KileView { class Manager; }
-namespace KileWidget { class Structure; class Konsole; }
+namespace KileWidget { class Structure; class Konsole; class ScriptsManagement; class PreviewWidget; }
 namespace KileTool { class QuickPreview; }
 namespace KileHelp { class Help; }
+namespace KileJScript { class Manager; }
+namespace KileEditorKeySequence { class Manager; }
+namespace KileTemplate { class Manager; }
 
 class KileInfo
 {
-
+	
 public:
 	KileInfo(QWidget *parent);
 	virtual ~KileInfo();
 
 public:
+	enum {bibinputs = 0,bstinputs, texinputs};
 	QString getName(Kate::Document *doc = 0, bool shrt = false);
 	QString getShortName(Kate::Document *doc = 0) { return getName(doc, true); }
 	QString getCompileName(bool shrt = false);
 	QString getFullFromPrettyName(const QString & name);
 	KURL::List getParentsFor(KileDocument::Info *);
+	bool getSinglemode() { return m_singlemode; }
 
 	QString getCurrentTarget() const { return m_currentTarget; }
 	void setTarget(const QString &target) { m_currentTarget=target; }
 
-	virtual Kate::Document* activeDocument() const;
+	virtual Kate::Document* activeTextDocument() const;
 
 	QString getSelection() const;
 	void clearSelection() const;
@@ -78,6 +87,8 @@ public:
 
 	QString lastModifiedFile(KileDocument::Info * info = 0L);
 
+	static QString documentTypeToString(KileDocument::Type type);
+
 private:
 	const QStringList* retrieveList(const QStringList* (KileDocument::Info::*getit)() const, KileDocument::Info * docinfo = 0L);
 	QStringList m_listTemp;
@@ -103,35 +114,50 @@ public:
 	KileWidget::Output *outputWidget() { return m_outputWidget; }
 	KileBottomBar *outputView() { return m_bottomBar; }
 	KileWidget::LogMsg *logWidget() { return m_logWidget; }
+	KileWidget::PreviewWidget *previewWidget () { return m_previewWidget; } 
 
 	KileDocument::Manager* docManager() const { return m_docManager; }
 	KileView::Manager* viewManager() const { return m_viewManager; }
 	KileTool::Manager* toolManager() const { return m_manager; }
+	KileJScript::Manager* scriptManager() const { return m_jScriptManager; }
+	KileEditorKeySequence::Manager* editorKeySequenceManager() const { return m_editorKeySequenceManager; }
 	KileTool::Factory* toolFactory() const { return m_toolFactory; }
 	KileDocument::EditorExtension *editorExtension() const { return m_edit; }
 	KileDocument::LatexCommands *latexCommands() const { return m_latexCommands; }
 	KileHelp::Help *help() const { return m_help; }
 	KileTool::QuickPreview *quickPreview() const { return m_quickPreview; }
+	KileDocument::Extensions *extensions() const { return m_extensions; }
+	KileTemplate::Manager *templateManager() const { return m_templateManager; }
 
 	//FIXME:refactor
 	KileFileSelect* fileSelector() const { return m_fileSelector; }
 	KileEventFilter* eventFilter() const { return m_eventFilter; }
 
 	QWidget *parentWidget() const { return m_parentWidget; }
-
+	
+	static QString expandEnvironmentVars(const QString &variable);
+	static QString checkOtherPaths(const QString &path,const QString &file, int type);
+	static QString checkOtherPaths(const KURL &url,const QString &file, int type){ return checkOtherPaths(url.path(),file, type); }
 protected:
 	KileDocument::Manager		*m_docManager;
 	KileView::Manager		*m_viewManager;
 	KileTool::Manager		*m_manager;
+	KileTemplate::Manager		*m_templateManager;
+	KileJScript::Manager		*m_jScriptManager;
+	KileEditorKeySequence::Manager	*m_editorKeySequenceManager;
 	KileTool::Factory		*m_toolFactory;
 	KileWidget::Konsole		*m_texKonsole;
 	KileWidget::Output		*m_outputWidget;
 	KileWidget::LogMsg		*m_logWidget;
+	KileWidget::ScriptsManagement	*m_scriptsManagementWidget;
 	KileBottomBar			*m_bottomBar;
+	KileWidget::PreviewWidget *m_previewWidget; 
+	QScrollView *m_previewView;
 
 	KileHelp::Help		*m_help;
 	KileDocument::EditorExtension 	*m_edit;
 	KileDocument::LatexCommands *m_latexCommands;
+	KileDocument::Extensions *m_extensions;
 	KileTool::QuickPreview *m_quickPreview;
 
 	QWidget *m_parentWidget;
