@@ -13,10 +13,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "kilelauncher.h"
+
+#include "kileinfo.h"
 #include "kiletool.h"
 #include "kiletoolmanager.h"
 #include "kiletool_enums.h"
-#include "kilelauncher.h"
 #include "docpart.h"
 #include "kileconfig.h"
 
@@ -24,7 +26,7 @@
 #include <qregexp.h>
 #include <qfileinfo.h>
 
-#include <kdebug.h>
+#include "kiledebug.h"
 #include <krun.h>
 #include <kprocess.h>
 #include <klocale.h>
@@ -43,7 +45,7 @@
 	
 	Launcher::~ Launcher()
 	{
-		kdDebug() << "DELETING launcher" << endl;
+		KILE_DEBUG() << "DELETING launcher" << endl;
 	}
 
 	ProcessLauncher::ProcessLauncher(const char * shellname /* =0 */) :
@@ -55,13 +57,13 @@
  		m_bstinputs(KileConfig::bstInputPaths()),
 		m_changeTo(true)
 	{
-		kdDebug() << "==KileTool::ProcessLauncher::ProcessLauncher()==============" << endl;
+		KILE_DEBUG() << "==KileTool::ProcessLauncher::ProcessLauncher()==============" << endl;
 
 		m_proc = new KShellProcess(shellname);
 		if (m_proc)
-			kdDebug() << "\tKShellProcess created" << endl;
+			KILE_DEBUG() << "\tKShellProcess created" << endl;
 		else
-			kdDebug() << "\tNO KShellProcess created" << endl;
+			KILE_DEBUG() << "\tNO KShellProcess created" << endl;
 
 		connect(m_proc, SIGNAL( receivedStdout(KProcess*, char*, int) ), this, SLOT(slotProcessOutput(KProcess*, char*, int ) ) );
  		connect(m_proc, SIGNAL( receivedStderr(KProcess*, char*, int) ),this, SLOT(slotProcessOutput(KProcess*, char*, int ) ) );
@@ -70,7 +72,7 @@
 
 	ProcessLauncher::~ProcessLauncher()
 	{
-		kdDebug() << "DELETING ProcessLauncher" << endl;
+		KILE_DEBUG() << "DELETING ProcessLauncher" << endl;
 		delete m_proc;
 	}
 
@@ -81,8 +83,8 @@
 
 	bool ProcessLauncher::launch()
 	{
-		kdDebug() << "KileTool::ProcessLauncher::launch()=================" << endl;
-		kdDebug() << "\tbelongs to tool " << tool()->name() << endl;
+		KILE_DEBUG() << "KileTool::ProcessLauncher::launch()=================" << endl;
+		KILE_DEBUG() << "\tbelongs to tool " << tool()->name() << endl;
 
 		QString msg, out = "*****\n*****     " + tool()->name() + i18n(" output: \n");
 
@@ -101,11 +103,11 @@
 		QString str;
 		tool()->translate(m_cmd);
 		tool()->translate(m_options);
-        	*m_proc  << m_cmd << m_options;
+		*m_proc  << m_cmd << m_options;
 		
 		if (m_proc)
 		{
-			out += QString("*****     ")+ m_cmd+ " " + m_options +QString("\n");
+			out += QString("*****     ")+ m_cmd+ ' ' + m_options + '\n';
 
 			QString src = tool()->source(false);
 			QString trgt = tool()->target();
@@ -114,7 +116,7 @@
 			else
 				msg = src + " => " + trgt;
 
-			msg += " ("+m_proc->args()[0]+")";
+			msg += " (" + m_proc->args()[0] + ')';
 			 
 			emit(message(Info,msg));
 
@@ -122,14 +124,20 @@
 			if ( tool()->isQuickie() ) 
 				m_texinputs = KileConfig::previewTeXPaths();
 
- 			kdDebug() << "\tenvironment variables are" << expandEnvironmentVars(m_texinputs + ":$TEXINPUTS") << expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS") << expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS") << tool()->name() << endl;
+			KILE_DEBUG() << "$PATH=" << tool()->manager()->info()->expandEnvironmentVars("$PATH") << endl;
+			KILE_DEBUG() << "$TEXINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_texinputs + ":$TEXINPUTS") << endl;
+			KILE_DEBUG() << "$BIBINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS") << endl;
+			KILE_DEBUG() << "$BSTINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS") << endl;
+			KILE_DEBUG() << "Tool name is "<< tool()->name() << endl;
+
+			m_proc->setEnvironment("PATH",tool()->manager()->info()->expandEnvironmentVars("$PATH"));
 
 			if (! m_texinputs.isEmpty())
-				m_proc->setEnvironment("TEXINPUTS", expandEnvironmentVars(m_texinputs + ":$TEXINPUTS"));
+				m_proc->setEnvironment("TEXINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_texinputs + ":$TEXINPUTS"));
 			if (! m_bibinputs.isEmpty())
-				m_proc->setEnvironment("BIBINPUTS", expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS"));
+				m_proc->setEnvironment("BIBINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS"));
 			if (! m_bstinputs.isEmpty())
-				m_proc->setEnvironment("BSTINPUTS", expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS"));
+				m_proc->setEnvironment("BSTINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS"));
 
 			out += "*****\n";
 			emit(output(out));
@@ -142,15 +150,15 @@
 
 	bool ProcessLauncher::kill()
 	{
-		kdDebug() << "==KileTool::ProcessLauncher::kill()==============" << endl;
+		KILE_DEBUG() << "==KileTool::ProcessLauncher::kill()==============" << endl;
 		if ( m_proc && m_proc->isRunning() )
 		{
-			kdDebug() << "\tkilling" << endl;
+			KILE_DEBUG() << "\tkilling" << endl;
 			return m_proc->kill();
 		}
 		else
 		{
-			kdDebug() << "\tno process or process not running" << endl;
+			KILE_DEBUG() << "\tno process or process not running" << endl;
 			return false;
 		}
 	}
@@ -188,14 +196,14 @@
 
 	void ProcessLauncher::slotProcessExited(KProcess*)
 	{
-		kdDebug() << "==KileTool::ProcessLauncher::slotProcessExited=============" << endl;
-		kdDebug() << "\t" << tool()->name() << endl;
+		KILE_DEBUG() << "==KileTool::ProcessLauncher::slotProcessExited=============" << endl;
+		KILE_DEBUG() << "\t" << tool()->name() << endl;
 
 		if (m_proc)
 		{
 			if (m_proc->normalExit())
 			{
-				kdDebug() << "\tnormal exit" << endl;
+				KILE_DEBUG() << "\tnormal exit" << endl;
 				int type = Info;
 				if (m_proc->exitStatus() != 0) 
 				{
@@ -210,7 +218,7 @@
 			}
 			else
 			{
-				kdDebug() << "\tabnormal exit" << endl;
+				KILE_DEBUG() << "\tabnormal exit" << endl;
 				emit(message(Error,i18n("finished abruptly")));
 				emit(done(AbnormalExit));
 			}
@@ -231,7 +239,7 @@
 		QString cmd = tool()->readEntry("command");
 		QString noclose = (tool()->readEntry("close") == "no") ? "--noclose" : "";
 		setCommand("konsole");
-		setOptions(noclose + " -T \"" + cmd + " (Kile)\" -e " + cmd + " " + tool()->readEntry("options"));
+		setOptions(noclose + " -T \"" + cmd + " (Kile)\" -e " + cmd + ' ' + tool()->readEntry("options"));
 
 		if ( KGlobal::dirs()->findExe(KRun::binaryName(cmd, false)).isNull() ) return false;
 
@@ -250,7 +258,7 @@
 
 	PartLauncher::~PartLauncher()
 	{
-		kdDebug () << "DELETING PartLauncher" << endl;
+		KILE_DEBUG () << "DELETING PartLauncher" << endl;
 	}
 
 	bool PartLauncher::launch()
@@ -268,7 +276,7 @@
 
 		QString name = shrt;
 		if ( dir[0] == '/' )
-			name = dir + "/" + shrt;
+			name = dir + '/' + shrt;
 
 
 		KLibFactory *factory = KLibLoader::self()->factory(m_libName);
@@ -291,10 +299,10 @@
 		}
 		else
 		{
-			QString cmd = QString(m_libName)+"->"+QString(m_className)+" "+m_options+" "+name;
-			out += "*****     " + cmd + "\n";
+			QString cmd = QString(m_libName) + "->" + QString(m_className) + ' ' + m_options + ' ' + name;
+			out += "*****     " + cmd + '\n';
 
-			msg = shrt+ " (" + tool()->readEntry("libName") + ")";
+			msg = shrt+ " (" + tool()->readEntry("libName") + ')';
 			emit(message(Info,msg));
 		}
 
