@@ -1,7 +1,9 @@
 /***************************************************************************
     begin                : Tue Aug 12 2003
     copyright            : (C) 2003 by Jeroen Wijnhout
+                           (C) 2006 by Michel Ludwig
     email                : Jeroen.Wijnhout@kdemail.net
+                           michel.ludwig@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -13,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "kileprojectview.h"
+
 #include <qheader.h>
 
 #include <klocale.h>
@@ -22,11 +26,11 @@
 #include <kurl.h>
 #include <krun.h>
 #include <kmimetype.h>
+#include <kurldrag.h>
 
 #include "kileinfo.h"
 #include "kiledocumentinfo.h"
 #include "kiledocmanager.h"
-#include "kileprojectview.h"
 
 const int KPV_ID_OPEN = 0, KPV_ID_SAVE = 1, KPV_ID_CLOSE = 2,
 	KPV_ID_OPTIONS = 3, KPV_ID_ADD = 4, KPV_ID_REMOVE = 5,
@@ -38,7 +42,12 @@ const int KPV_ID_OPEN = 0, KPV_ID_SAVE = 1, KPV_ID_CLOSE = 2,
  */
 void KileProjectViewItem::urlChanged(const KURL &url)
 {
-	setURL(url); setText(0,url.fileName());
+	// don't allow empty URLs
+	if(!url.isEmpty()) 
+	{
+		setURL(url);
+		setText(0, url.fileName());
+	}
 }
 
 void KileProjectViewItem::nameChanged(const QString & name)
@@ -48,7 +57,7 @@ void KileProjectViewItem::nameChanged(const QString & name)
 
 void KileProjectViewItem::isrootChanged(bool isroot)
 {
-	kdDebug() << "SLOT isrootChanged " << text(0) << " to " << isroot << endl;
+	KILE_DEBUG() << "SLOT isrootChanged " << text(0) << " to " << isroot << endl;
 	if (isroot)
 	{
 		setPixmap(0,SmallIcon("masteritem"));
@@ -64,12 +73,29 @@ void KileProjectViewItem::isrootChanged(bool isroot)
 	}
 }
 
+void KileProjectViewItem::slotURLChanged(KileDocument::Info*, const KURL & url)
+{
+	urlChanged(url);
+}
+
 int KileProjectViewItem::compare(QListViewItem * i, int col, bool ascending) const
 {
 	KileProjectViewItem *item = dynamic_cast<KileProjectViewItem*>(i);
-	if ( (item->type() == KileType::Folder) &&  (type() != KileType::Folder) ) return 1;
-	else if ( (item->type() != KileType::Folder) &&  (type() == KileType::Folder) ) return -1;
-	else return QListViewItem::compare(i, col, ascending);
+
+	// sort: 
+	//  - first:  container items in fixed order (projectfile, packages, images, other)
+	//  - second: root items without container (sorted in ascending order)
+	if ( item->type() == KileType::Folder )
+	{
+		if ( type() != KileType::Folder ) 
+			return 1;
+		else 
+			return ( m_folder < item->folder() ) ? -1 : 1;
+	}
+	else if ( type() == KileType::Folder ) 
+		return -1;
+	else 
+		return QListViewItem::compare(i, col, ascending);
 }
 
 /*
@@ -83,12 +109,17 @@ KileProjectView::KileProjectView(QWidget *parent, KileInfo *ki) : KListView(pare
 	setFocusPolicy(QWidget::ClickFocus);
 	header()->hide();
 	setRootIsDecorated(true);
+	setAllColumnsShowFocus(true);
+	setFullWidth(true);
+	setSelectionModeExt(KListView::NoSelection);
 
 	m_popup = new KPopupMenu(this, "projectview_popup");
 
 	connect(this, SIGNAL(contextMenu(KListView *, QListViewItem *, const QPoint & )), this,SLOT(popup(KListView *, QListViewItem * , const QPoint & )));
 
 	connect(this, SIGNAL(executed(QListViewItem*)), this, SLOT(slotClicked(QListViewItem*)));
+	setAcceptDrops(true);
+	connect(this, SIGNAL(dropped(QDropEvent *, QListViewItem *)), m_ki->docManager(), SLOT(openDroppedURLs(QDropEvent *)));
 }
 
 void KileProjectView::slotClicked(QListViewItem *item)
@@ -116,21 +147,25 @@ void KileProjectView::slotClicked(QListViewItem *item)
 					KRun::runURL(itm->url(), pMime->name());
 			}
 		}
+		clearSelection();
 	}
 }
 
 void KileProjectView::slotFile(int id)
 {
 	KileProjectViewItem *item = static_cast<KileProjectViewItem*>(currentItem());
-	if (item && item->type() == KileType::File)
+	if (item )
 	{
-		switch (id)
+		if ( item->type() == KileType::File )
 		{
-			case KPV_ID_OPEN : emit(fileSelected(item->url())); break;
-			case KPV_ID_SAVE : emit(saveURL(item->url())); break;
-			case KPV_ID_ADD : emit(addToProject(item->url())); break;
-			case KPV_ID_CLOSE : emit(closeURL(item->url())); break;
-			default : break;
+			switch (id)
+			{
+				case KPV_ID_OPEN : emit(fileSelected(item->url())); break;
+				case KPV_ID_SAVE : emit(saveURL(item->url())); break;
+				case KPV_ID_ADD : emit(addToProject(item->url())); break;
+				case KPV_ID_CLOSE : emit(closeURL(item->url())); return; //don't access "item" later on
+				default : break;
+			}
 		}
 	}
 }
@@ -138,26 +173,28 @@ void KileProjectView::slotFile(int id)
 void KileProjectView::slotProjectItem(int id)
 {
 	KileProjectViewItem *item = static_cast<KileProjectViewItem*>(currentItem());
-	if (item && (item->type() == KileType::ProjectItem || item->type() == KileType::ProjectExtra))
+	if ( item )
 	{
-		switch (id)
+		if ( item->type()==KileType::ProjectItem || item->type()==KileType::ProjectExtra )
 		{
-			case KPV_ID_OPEN : emit(fileSelected(item->projectItem())); break;
-			case KPV_ID_SAVE : emit(saveURL(item->url())); break;
-			case KPV_ID_REMOVE :
-				emit(removeFromProject(item->projectItem()));
-				break;
-			case KPV_ID_INCLUDE :
-				if (item->text(1) == "*") item->setText(1,"");
-				else item->setText(1,"*");
-
-				emit(toggleArchive(item->projectItem()));
-				break;
-			case KPV_ID_CLOSE : emit(closeURL(item->url())); break;
-			case KPV_ID_OPENWITH :
-				KRun::displayOpenWithDialog(item->url());
-				break;
-			default : break;
+			switch (id)
+			{
+				case KPV_ID_OPEN : emit(fileSelected(item->projectItem())); break;
+				case KPV_ID_SAVE : emit(saveURL(item->url())); break;
+				case KPV_ID_REMOVE :
+					emit(removeFromProject(item->projectItem()));
+					break;
+				case KPV_ID_INCLUDE :
+					if (item->text(1) == "*") item->setText(1,"");
+					else item->setText(1,"*");
+					emit(toggleArchive(item->projectItem()));
+					break;
+				case KPV_ID_CLOSE : emit(closeURL(item->url())); break; //we can access "item" later as it isn't deleted
+				case KPV_ID_OPENWITH :
+					KRun::displayOpenWithDialog(item->url());
+					break;
+				default : break;
+			}
 		}
 	}
 }
@@ -165,17 +202,20 @@ void KileProjectView::slotProjectItem(int id)
 void KileProjectView::slotProject(int id)
 {
 	KileProjectViewItem *item = static_cast<KileProjectViewItem*>(currentItem());
-	if (item && item->type() == KileType::Project)
+	if ( item )
 	{
-		switch (id)
+		if ( item->type() == KileType::Project )
 		{
-			case KPV_ID_BUILDTREE : emit(buildProjectTree(item->url())); break;
-			case KPV_ID_OPTIONS : emit(projectOptions(item->url())); break;
-			case KPV_ID_CLOSE : emit(closeProject(item->url())); break;
-			case KPV_ID_ARCHIVE : emit(projectArchive(item->url())); break;
-			case KPV_ID_ADDFILES : emit(addFiles(item->url())); break;
-			case KPV_ID_OPENALLFILES : emit(openAllFiles(item->url())); break;
-			default : break;
+			switch (id)
+			{
+				case KPV_ID_BUILDTREE : emit(buildProjectTree(item->url())); break;
+				case KPV_ID_OPTIONS : emit(projectOptions(item->url())); break;
+				case KPV_ID_CLOSE : emit(closeProject(item->url())); return; //don't access "item" later on
+				case KPV_ID_ARCHIVE : emit(projectArchive(item->url())); break;
+				case KPV_ID_ADDFILES : emit(addFiles(item->url())); break;
+				case KPV_ID_OPENALLFILES : emit(openAllFiles(item->url())); break;
+				default : break;
+			}
 		}
 	}
 }
@@ -188,6 +228,8 @@ void KileProjectView::slotRun(int id)
 		KRun::displayOpenWithDialog(itm->url());
 	else
 		KRun::run(*m_offerList[id-1], itm->url());
+
+	itm->setSelected(false);
 }
 
 //FIXME clean this mess up
@@ -292,7 +334,7 @@ void KileProjectView::popup(KListView *, QListViewItem *  item, const QPoint &
 
 void KileProjectView::makeTheConnection(KileProjectViewItem *item)
 {
-	kdDebug() << "\tmakeTheConnection " << item->text(0) << endl;
+	KILE_DEBUG() << "\tmakeTheConnection " << item->text(0) << endl;
 
 	if (item->type() == KileType::Project)
 	{
@@ -304,10 +346,10 @@ void KileProjectView::makeTheConnection(KileProjectViewItem *item)
 	}
 	else
 	{
-		KileDocument::Info *docinfo = m_ki->docManager()->infoFor(item->url().path());
+		KileDocument::TextInfo *docinfo = m_ki->docManager()->textInfoFor(item->url().path());
 		item->setInfo(docinfo);
-		if (docinfo ==0 ) {kdDebug() << "\tmakeTheConnection COULD NOT FIND A DOCINFO" << endl; return;}
-		connect(docinfo, SIGNAL(nameChanged(const KURL&)),  item, SLOT(urlChanged(const KURL&)));
+		if (docinfo ==0 ) {KILE_DEBUG() << "\tmakeTheConnection COULD NOT FIND A DOCINFO" << endl; return;}
+		connect(docinfo, SIGNAL(urlChanged(KileDocument::Info*, const KURL&)),  item, SLOT(slotURLChanged(KileDocument::Info*, const KURL&)));
 		connect(docinfo, SIGNAL(isrootChanged(bool)), item, SLOT(isrootChanged(bool)));
 		//set the pixmap
 		item->isrootChanged(docinfo->isLaTeXRoot());
@@ -324,28 +366,54 @@ KileProjectViewItem* KileProjectView::folder(const KileProjectItem *pi, KileProj
 		return 0;
 	}
 
-	if (parent->type() == KileType::Folder)
+	// we have already found the parent folder
+	if ( parent->type() == KileType::Folder )
 		return parent;
 
-	//create the folder item
+	// we are looking at the children, if there is an existing folder for this type
 	KileProjectViewItem *folder;
 
-	switch (pi->type()) {
-	case (KileProjectItem::Package):
-		folder = new KileProjectViewItem(parent, i18n("packages"));
-		break;
-	case (KileProjectItem::Image):
-		folder = new KileProjectViewItem(parent, i18n("images"));
-		break;
-	case (KileProjectItem::Other): default :
-		folder = new KileProjectViewItem(parent, i18n("other"));
-		break;
+	// determine the foldername for this type
+	QString foldername;
+	switch ( pi->type() ) 
+	{
+		case (KileProjectItem::ProjectFile):
+			foldername = i18n("projectfile");
+			break;
+		case (KileProjectItem::Package):
+			foldername = i18n("packages");
+			break;
+		case (KileProjectItem::Image):
+			foldername = i18n("images");
+			break;
+		case (KileProjectItem::Other): 
+		default :
+			foldername = i18n("other");
+			break;
 	}
 
-	kdDebug() << "new folder: " << parent->url().url() << endl;
+	// if there already a folder for this type on this level?
+	bool found = false;
+	folder = parent->firstChild();
+	while ( folder )
+	{
+		if ( folder->text(0) == foldername )
+		{
+			found = true;
+			break;
+		}
+		folder = folder->nextSibling();
+	}
+	
+	// if no folder was found, we must create a new one
+	if ( ! found )
+	{
+		folder = new KileProjectViewItem(parent,foldername);
+		KILE_DEBUG() << "new folder: " << parent->url().url() << endl;
 
-	folder->setFolder(pi->type());
-	folder->setType(KileType::Folder);
+		folder->setFolder(pi->type());
+		folder->setType(KileType::Folder);
+	}
 
 	return folder;
 }
@@ -410,30 +478,29 @@ KileProjectViewItem* KileProjectView::parentFor(const KileProjectItem *projitem,
 	if (parpi) {
 		//find parent viewitem that has an URL parpi->url()
 		QListViewItemIterator it( projvi );
-		kdDebug() << "\tlooking for " << parpi->url().path() << endl;
+		KILE_DEBUG() << "\tlooking for " << parpi->url().path() << endl;
 		while (it.current())
 		{
 			vi = static_cast<KileProjectViewItem*>(*it);
-			kdDebug() << "\t\t" << vi->url().path() << endl;
+			KILE_DEBUG() << "\t\t" << vi->url().path() << endl;
 			if (vi->url() == parpi->url())
 			{
 				parpvi = vi;
-				kdDebug() << "\t\tfound" <<endl;
+				KILE_DEBUG() << "\t\tfound" <<endl;
 				break;
 			}
 			++it;
 		}
 
-		kdDebug() << "\t\tnot found" << endl;
+		KILE_DEBUG() << "\t\tnot found" << endl;
 	}
 	else {
-		kdDebug() << "\tlooking for folder type " << projitem->type() << endl;
+		KILE_DEBUG() << "\tlooking for folder type " << projitem->type() << endl;
 		for (parpvi = parpvi->firstChild(); parpvi; parpvi = parpvi->nextSibling())
 		{
-			if ((parpvi->type() == KileType::Folder) &&
-				(parpvi->folder() == projitem->type()))
+			if ( (parpvi->type() == KileType::Folder) && (parpvi->folder() == projitem->type()) )
 			{
-				kdDebug() << "\t\tfound" << endl;
+				KILE_DEBUG() << "\t\tfound" << endl;
 				break;
 			}
 		}
@@ -444,7 +511,7 @@ KileProjectViewItem* KileProjectView::parentFor(const KileProjectItem *projitem,
 
 KileProjectViewItem* KileProjectView::add(KileProjectItem *projitem, KileProjectViewItem * projvi /* = 0*/)
 {
-	kdDebug() << "\tKileProjectView::adding projectitem " << projitem->path() << endl;
+	KILE_DEBUG() << "\tKileProjectView::adding projectitem " << projitem->path() << endl;
 
 	const KileProject *project = projitem->project();
 
@@ -453,7 +520,7 @@ KileProjectViewItem* KileProjectView::add(KileProjectItem *projitem, KileProject
 		projvi= projectViewItemFor(project->url());
 	}
 
-	kdDebug() << "\tparent projectviewitem " << projvi->url().fileName() << endl;
+	KILE_DEBUG() << "\tparent projectviewitem " << projvi->url().fileName() << endl;
 
 	KileProjectViewItem *item, *parent;
 
@@ -461,17 +528,20 @@ KileProjectViewItem* KileProjectView::add(KileProjectItem *projitem, KileProject
 	case (KileProjectItem::Source):
 		item = new KileProjectViewItem(projvi, projitem);
 		item->setType(KileType::ProjectItem);
+		item->setPixmap(0,SmallIcon("projectitem"));
 		break;
 	case (KileProjectItem::Package):
 		parent = folder(projitem, projvi);
 		item = new KileProjectViewItem(parent, projitem);
 		item->setType(KileType::ProjectItem);
+		item->setPixmap(0,SmallIcon("projectitem"));
 		break;
 	case (KileProjectItem::ProjectFile):
 	default:
 		parent = folder(projitem, projvi);
 		item = new KileProjectViewItem(parent, projitem);
 		item->setType(KileType::ProjectExtra);
+		item->setPixmap(0,SmallIcon( (projitem->type()==KileProjectItem::ProjectFile) ? "kile" : "file" ));
 		break;
 	}
 
@@ -497,13 +567,13 @@ void KileProjectView::addTree(KileProjectItem *projitem, KileProjectViewItem * p
 
 void KileProjectView::refreshProjectTree(const KileProject *project)
 {
-	kdDebug() << "\tKileProjectView::refreshProjectTree(" << project->name() << ")" << endl;
+	KILE_DEBUG() << "\tKileProjectView::refreshProjectTree(" << project->name() << ")" << endl;
 	KileProjectViewItem *parent= projectViewItemFor(project->url());
 
 	//clean the tree
 	if (parent)
 	{
-		kdDebug() << "\tusing parent projectviewitem " << parent->url().fileName() << endl;
+		KILE_DEBUG() << "\tusing parent projectviewitem " << parent->url().fileName() << endl;
 		parent->setFolder(-1);
 		QListViewItem *vi = parent->firstChild(), *next;
 		while (vi)
@@ -533,7 +603,7 @@ void KileProjectView::refreshProjectTree(const KileProject *project)
 
 void KileProjectView::add(const KURL & url)
 {
-	kdDebug() << "\tKileProjectView::adding item " << url.path() << endl;
+	KILE_DEBUG() << "\tKileProjectView::adding item " << url.path() << endl;
 	//check if file is already present
 	QListViewItemIterator it( this );
 	KileProjectViewItem *item;
@@ -596,7 +666,7 @@ void KileProjectView::removeItem(const KileProjectItem *projitem, bool open)
 		item = static_cast<KileProjectViewItem*>(*it);
 		if ( (item->type() == KileType::ProjectItem) && (item->projectItem() == projitem) )
 		{
-			kdDebug() << "removing projectviewitem" << endl;
+			KILE_DEBUG() << "removing projectviewitem" << endl;
 			item->parent()->takeItem(item);
 			delete item;
 		}
@@ -613,4 +683,9 @@ void KileProjectView::removeItem(const KileProjectItem *projitem, bool open)
 
 }
 
+bool KileProjectView::acceptDrag(QDropEvent *e) const
+{
+	return KURLDrag::canDecode(e); // only accept URL drops
+}
+
 #include "kileprojectview.moc"
