@@ -492,8 +492,7 @@ namespace KileWidget
 				if ( m_lastSectioning && (m_lastLine==line-1 || m_lastLine==line) )
 					m_lastSectioning->setLabel(title);
 			}
-			else if ( m_lastType==KileStruct::BeamerBeginFrame )
-			{
+			else if(m_lastType == KileStruct::BeamerBeginFrame && m_lastFrameEnv) {
 				m_lastFrameEnv->setLabel(title);
 			}
 
@@ -658,8 +657,7 @@ namespace KileWidget
 		
 		if ( item->type() & (KileStruct::Input | KileStruct::Bibliography | KileStruct::Graphics) )
 		{
-			QString fname = item->title();
-			
+			QString fname = item->title();	
 			
 			if(fname.find(suffix) != -1) // check if we have a suffix, if not add standard suffixes
 			{
@@ -699,8 +697,23 @@ namespace KileWidget
 				else
 					emit(fileOpen(url, QString::null));
 			}
-			else
-			{
+			else if( item->type() == KileStruct::Bibliography ){
+				fname = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::bibinputs);
+				fi.setFile(fname);
+				url.setPath(fname);
+				if(fi.isReadable()){
+					emit(fileOpen(url, QString::null));
+				}
+			}
+			else if( item->type() == KileStruct::Input ){
+				fname = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::texinputs);
+				fi.setFile(fname);
+				url.setPath(fname);
+				if(fi.isReadable()){
+					emit(fileOpen(url, QString::null));
+				}
+			}
+			else{
 				if ( KMessageBox::warningYesNo(this, i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?").arg(fname), i18n("Cannot Find File"))
 			== KMessageBox::Yes)
 				{
@@ -946,12 +959,18 @@ namespace KileWidget
 
 	////////////////////// Structure: find sectioning //////////////////////
 
-	bool Structure::findSectioning(Kate::Document *doc, uint row, uint col, bool backwards, uint &sectRow, uint &sectCol)
+	bool Structure::findSectioning(KileListViewItem *refItem, Kate::Document *doc, uint row, uint col, bool backwards, bool checkLevel, uint &sectRow, uint &sectCol)
 	{
 		KileDocument::TextInfo *docinfo = m_ki->docManager()->textInfoFor(doc);
-		if ( ! docinfo )
+		
+		if ( ! docinfo ){
 			return false;
-
+		}
+		
+		if( checkLevel && !refItem ){ // only allow a refItem == NULL if checkLevel is false
+			return false;
+		}
+		
 		bool found = false;
 		uint foundRow,foundCol;
 		StructureList *structurelist = viewFor(docinfo);
@@ -959,7 +978,7 @@ namespace KileWidget
 		while ( it.current() ) 
 		{
 			KileListViewItem *item = (KileListViewItem *)(it.current());
-			if  ( item->type() == KileStruct::Sect )
+			if  (item->type() == KileStruct::Sect && (!checkLevel || item->level() <= refItem->level()))
 			{
 				foundRow = item->startline() - 1;
 				foundCol = item->startcol() - 1;
